@@ -240,6 +240,13 @@ static const char help_string[] =
     "      - part size, in MB, for each multipart request.\n"
     "      The minimum value is 5 MB and the maximum value is 5 GB.\n"
     "\n"
+    "   multipart_copy_size (default=\"512\")\n"
+    "      - part size, in MB, for each multipart copy request, used for\n"
+    "      renames and mixupload.\n"
+    "      The minimum value is 5 MB and the maximum value is 5 GB.\n"
+    "      Must be at least 512 MB to copy the maximum 5 TB object size\n"
+    "      but lower values may improve performance.\n"
+    "\n"
     "   max_dirty_data (default=\"5120\")\n"
     "      - flush dirty data to S3 after a certain number of MB written.\n"
     "      The minimum value is 50 MB.  -1 value means disable.\n"
@@ -253,6 +260,10 @@ static const char help_string[] =
     "        space is smaller than this value, s3fs do not use diskspace\n"
     "        as possible in exchange for the performance.\n"
     "\n"
+    "   multipart_threshold (default=\"25\")\n"
+    "      - threshold, in MB, to use multipart upload instead of\n"
+    "        single-part.  Must be at least 5 MB.\n"
+    "\n"
     "   singlepart_copy_limit (default=\"512\")\n"
     "      - maximum size, in MB, of a single-part copy before trying \n"
     "      multipart copy.\n"
@@ -371,6 +382,10 @@ static const char help_string[] =
     "        the virtual-host request style, by using the older path request\n"
     "        style.\n"
     "\n"
+    "   listobjectsv2 (use ListObjectsV2)\n"
+    "        Issue ListObjectsV2 instead of ListObjects, useful on object\n"
+    "        stores without ListObjects support.\n"
+    "\n"
     "   noua (suppress User-Agent header)\n"
     "        Usually s3fs outputs of the User-Agent in \"s3fs/<version> (commit\n"
     "        hash <hash>; <using ssl library name>)\" format.\n"
@@ -461,6 +476,13 @@ static const char help_string[] =
     "        If \"body\" is specified, some API communication body data will be\n"
     "        output in addition to the debug message output as \"normal\".\n"
     "\n"
+    "   no_time_stamp_msg - no time stamp in debug message\n"
+    "        The time stamp is output to the debug message by default.\n"
+    "        If this option is specified, the time stamp will not be output\n"
+    "        in the debug message.\n"
+    "        It is the same even if the environment variable \"S3FS_MSGTIMESTAMP\"\n"
+    "        is set to \"no\".\n"
+    "\n"
     "   set_check_cache_sigusr1 (default is stdout)\n"
     "        If the cache is enabled, you can check the integrity of the\n"
     "        cache file and the cache file's stats info file.\n"
